<?php
/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CHARSET","ISO-8859-1");
define("_SEARCH","Zoek");
define("_LOGIN","Inloggen");
define("_WRITES","schrijft");
define("_POSTEDON","Geplaatst op");
define("_NICKNAME","Loginnaam");
define("_PASSWORD","Wachtwoord");
define("_WELCOMETO","Welkom op");
define("_EDIT","Bewerken");
define("_DELETE","Verwijder");
define("_POSTEDBY","Geplaatst door");
define("_READS","maal gelezen");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Ga terug</a> ]");
define("_COMMENTS","opmerkingen");
define("_PASTARTICLES","Vorige artikelen");
define("_OLDERARTICLES","Oudere artikelen");
define("_BY","door");
define("_ON","op");
define("_LOGOUT","Afmelden");
define("_WAITINGCONT","Wachtende inhoud");
define("_SUBMISSIONS","Ingeleverde stukken");
define("_WREVIEWS","Wachtende periodieken");
define("_WLINKS","Wachtende links");
define("_EPHEMERIDS","Ephemerids");
define("_ONEDAY","Een dag zoals vandaag...");
define("_ASREGISTERED","Nog geen lid? U kunt een account <a href=\"modules.php?name=Your_Account\">aanvragen</a>. Als geregistreerde gebruiker krijgt u voordelen zoals de Thema-manager, opmerkingsconfiguratie en kunt u opmerkingen plaatsen onder uw eigen naam.");
define("_MENUFOR","Menu voor");
define("_NOBIGSTORY","Vandaag is er nog geen groot verhaal geplaatst.");
define("_BIGSTORY","Het meest gelezen verhaal van vandaag is:");
define("_SURVEY","Onderzoek");
define("_POLLS","Peilingen");
define("_PCOMMENTS","Opmerkingen:");
define("_RESULTS","Uitslagen");
define("_HREADMORE","Lees meer...");
define("_CURRENTLY","Er zijn op dit moment,");
define("_GUESTS","gast(en) en");
define("_MEMBERS","lid(leden) die online zijn.");
define("_YOUARELOGGED","U bent ingelogd als");
define("_YOUHAVE","U hebt");
define("_PRIVATEMSG","priv-bericht(en).");
define("_YOUAREANON","U bent een gast. U kunt gratis een account aanvragen door <a href=\"modules.php?name=Your_Account\">hier</a> te klikken");
define("_NOTE","Noot:");
define("_ADMIN","Admin:");
define("_WERECEIVED","We ontvingen");
define("_PAGESVIEWS","paginabezoeken sinds");
define("_TOPIC","Onderwerp");
define("_UDOWNLOADS","Downloads");
define("_VOTE","Stem");
define("_VOTES","Stemmen");
define("_MVIEWADMIN","Beeld: alleen beheerders");
define("_MVIEWUSERS","Beeld: alleen leden");
define("_MVIEWANON","Beeld: alleen niet-leden");
define("_MVIEWALL","Beeld: alle bezoekers");
define("_EXPIRELESSHOUR","Vervalt binnen n uur");
define("_EXPIREIN","Vervalt over");
define("_HTTPREFERERS","HTTP Referers");
define("_UNLIMITED","Ongelimiteerd");
define("_HOURS","Uren");
define("_RSSPROBLEM","Er is een probleem met de koppen van deze site");
define("_SELECTLANGUAGE","Kies taal");
define("_SELECTGUILANG","Kies interface taal:");
define("_NONE","Geen");
define("_BLOCKPROBLEM","<center>Er is een probleem met dit blok.</center>");
define("_BLOCKPROBLEM2","<center>Dit blok heeft geen inhoud.</center>");
define("_MODULENOTACTIVE","Sorry, deze module is niet actief");
define("_NOACTIVEMODULES","Inactieve Modules");
define("_FORADMINTESTS","(voor Admin testen)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Geen Toegang");
define("_RESTRICTEDAREA", "Voorbehouden zone.");
define("_MODULEUSERS", "Onze verontschuldigingen, dit onderdeel is enkel toegankelijk voor <i>geregistreerde bezoekers</i><br><br>Je kan gratis registreren door <a href=\"modules.php?name=Your_Account&op=new_user\">hier</a> te klikken,<br>daarna kan je dit onderdeel raadplegen zonder beperkingen.<br>Dank u.<br><br>");
define("_MODULESADMINS", "Onze verontschuldigingen, dit onderdeel is enkel toegankelijk voor <i>Beheerders</i><br><br>");
define("_HOME","Startpagina");
define("_HOMEPROBLEM","Oei... Probleem... Hier is geen startpagina!");
define("_ADDAHOME","Module toevoegen op startpagina");
define("_HOMEPROBLEMUSER","Er is een probleem op de startpagina. Gelieve dit nadien te controleren.");
define("_MORENEWS","Meer in het onderdeel NIEUWS");
define("_ALLCATEGORIES","Alle categorien");
define("_DATESTRING","%A %d %B @ %T GMT+1");
define("_DATESTRING2","%A %d %B");
define("_DATE","Datum");
define("_HOUR","Uur");
define("_UMONTH","Maand");
define("_YEAR","Jaar");
define("_JANUARY","Januari");
define("_FEBRUARY","Februari");
define("_MARCH","Maart");
define("_APRIL","April");
define("_MAY","Mei");
define("_JUNE","Juni");
define("_JULY","Juli");
define("_AUGUST","Augustus");
define("_SEPTEMBER","September");
define("_OCTOBER","Oktober");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_BWEL","Welkom");
define("_BPM","Priv-berichten");
define("_BUNREAD","Ongelezen");
define("_BREAD","Lees");
define("_BMEMP","Lidmaatschap");
define("_BLATEST","Laatste");
define("_BTD","Nieuw vandaag");
define("_BYD","Nieuw gisteren");
define("_BOVER","Algemeen");
define("_BVISIT","Bezoekers Online");
define("_BVIS","Bezoekers");
define("_BMEM","Leden");
define("_BTT","Totaal");
define("_BON","Nu Online");
define("_BREG","Registreer");
define("_BROADCAST","Uitgezonden Publieke Berichten");
define("_BROADCASTFROM","Publieke Berichten van");
define("_TURNOFFMSG","Zet Publieke Berichten uit");
define("_JOURNAL","Journaal");
define("_READMYJOURNAL","Lees mijn Journaal");
define("_ADD","Toevoegen");
define("_YES","Ja");
define("_NO","Nee");
define("_INVISIBLEMODULES","Onzichtbare Modules");
define("_ACTIVEBUTNOTSEE","(Actieve maar onzichtbare link)");
define("_THISISAUTOMATED","Dit is een automatisch E-mail om u te laten weten dat uw banner advertering in uw site nu beindigd is.");
define("_THERESULTS","De resultaten van uw campagne zijn als volgt:");
define("_TOTALIMPRESSIONS","Totaal gemaakte Impressies:");
define("_CLICKSRECEIVED","Kliks ontvangen:");
define("_IMAGEURL","Beeld URL");
define("_CLICKURL","Klik URL:");
define("_ALTERNATETEXT","Alternatieve Tekst:");
define("_HOPEYOULIKED","Hopelijks bent u tevreden over onze diensten. Wij zouden u graag wederom verwelkomen als adverteerder.");
define("_THANKSUPPORT","Bedankt voor uw Support");
define("_TEAM","Team");
define("_BANNERSFINNISHED","Banners Toevoegingen Beindigd");
define("_MODREQLINKS","Bewerk Links");
define("_BROKENLINKS","Gebroken Links");
define("_MODREQDOWN","Bewerk Downloads");
define("_BROKENDOWN","Gebroken Downloads");
define("_PAGEGENERATION","Pagina Rendering:");
define("_SECONDS","Seconden");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>
